#
# spec file for package bomctl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bomctl
Version:        0.4.2
Release:        1.2
Summary:        Format agnostic SBOM tooling
License:        Apache-2.0
URL:            https://github.com/bomctl/bomctl
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.23
BuildRequires:  zsh

%description
bomctl is format-agnostic Software Bill of Materials (SBOM) tooling, which is
intended to bridge the gap between SBOM generation and SBOM analysis tools. It
focuses on supporting more complex SBOM operations on multiple SBOM files that
represent systems by being opinionated on only supporting the NTIA minimum
fields or other fields supported by protobom.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
VERSION_MAJOR="$(echo %{version} | awk -F. '{print $1}')"
VERSION_MINOR="$(echo %{version} | awk -F. '{print $2}')"
VERSION_PATCH="$(echo %{version} | awk -F. '{print $3}')"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -trimpath \
   -ldflags=" \
   -X=github.com/bomctl/bomctl/cmd.VersionMajor=${VERSION_MAJOR} \
   -X=github.com/bomctl/bomctl/cmd.VersionMinor=${VERSION_MINOR} \
   -X=github.com/bomctl/bomctl/cmd.VersionPatch=${VERSION_PATCH} \
   -X=github.com/bomctl/bomctl/cmd.VersionPre= \
   -X=github.com/bomctl/bomctl/cmd.BuildDate=${BUILD_DATE}" \
   -o bin/%{name}

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%check
%{buildroot}/%{_bindir}/%{name} version 2>&1 | grep v%{version}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Thu Jan  9 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.4.2:
  * New features
  - feat: Output Sboms without Modification (#210) (@ashearin)
  - feat: SBOM Aliases (#129) (@lmphil)
  - feat: SBOM linking (#223) (@jhoward-lm)
  - feat: add base document db annotation,
    WithSourceDocumentAnnotations and
    WithRevisedDocumentAnnotations functions (#211) (@ashearin)
  - feat: add latest document annotation (#230) (@ashearin)
  - feat: add link command stubs (#222) (@jhoward-lm)
  - feat: bomctl push subcommand OCI client functionality (#139)
    (@jhoward-lm)
  - feat: document annotations for source data, hash, format, and
    URL (#153) (@jhoward-lm)
  - feat: github client fetch support (#209) (@lallevato-lm)
  - feat: gitlab fetch (#229) (@lmphil)
  - feat: implement autocomplete (#238) (@lallevato-lm)
  * Bug fixes
  - fix: Fix typo in MAINTAINERS (#180) (@evankanderson)
  - fix: Print DocID for list cmd. Dynamic id/alias column width
    (#165) (@ashearin)
  - fix: add cyclonedx 1.6 support (#188) (@ashearin)
  - fix: update compare_docs function (#202) (@ashearin)
  * Documentation
  - docs: ADR-0006 sbom merge (#111) (@pkwiatkowski1)
  - docs: ADR-0007 sbom diff (#112) (@mfrystacky)
  - docs: ADR-0008 storage and retrieval without modification
    (#194) (@ashearin)
  - docs: ADR-0009 SBOM Linking (#164) (@lmphil)
  - docs: Roadmap Updates (#161) (@idunbarh)
  - docs: add ADR for auth types and encrypted secrets (#104)
    (@jhoward-lm)
  * Other changes
  - refactor: add Unpack function, rename to match package (#239)
    (@jhoward-lm)
  - refactor: add choiceValue type for static sets of flag
    options (#240) (@jhoward-lm)
  - refactor: add sliceutils helper package for dev convenience
    (#163) (@jhoward-lm)
  - refactor: break out Fetcher and Pusher from Client interface,
    add PrepareFetch method (#245) (@jhoward-lm)
  - refactor: internal option to force list output if desired
    (#241) (@jhoward-lm)
  - refactor: stage all externally referenced SBOMs before push
    (#155) (@jhoward-lm)
  - test: add cmd format/encoding unit tests, update e2e tests
    (#185) (@ashearin)
  - test: add unit tests for alias/tags DB functions (#174)
    (@lmphil)
  - test: client fetch unit tests (#205) (@jhoward-lm)
  - test: integration testing of functionality (#169) (@ashearin)
* Sat Dec 28 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package bomctl: Format agnostic SBOM tooling
